

class BaseFieldPermission(object):

    def has_permission(self, request):
        return True


class AllowAny(BaseFieldPermission):

    def has_permission(self, request):
        return True


class AllowNone(BaseFieldPermission):

    def has_permission(self, request):
        return False


class IsAuthenticated(BaseFieldPermission):

    def has_permission(self, request):
        return request.user and request.user.is_authenticated()


from rest_framework.pagination import PaginationSerializer, DefaultObjectSerializer
from rest_framework.serializers import ListSerializer


class FieldPermissionSerializerMixin(object):

    @property
    def fields(self):
        ret = super(FieldPermissionSerializerMixin, self).fields
        request = self._context["request"]

        for field_name, field in ret.items():
            if hasattr(field, 'check_permission') and (not field.check_permission(request)):
                ret.pop(field_name)

        return ret


class ContextPassingPaginationSerializer(PaginationSerializer):

    def __init__(self, *args, **kwargs):
        """
        Override init to add in the object serializer field on-the-fly.
        """
        super(ContextPassingPaginationSerializer, self).__init__(*args, **kwargs)
        results_field = self.results_field

        try:
            object_serializer = self.Meta.object_serializer_class
        except AttributeError:
            object_serializer = DefaultObjectSerializer

        self.fields[results_field] = ListSerializer(
            child=object_serializer(context=kwargs["context"]),
            source='object_list'
        )


from rest_framework import fields


class PermissionMixin(object):

    def __init__(self, *args, permission_classes=(), **kwargs):

        super(PermissionMixin, self).__init__(*args, **kwargs)
        self.permission_classes = permission_classes

    def check_permission(self, request):
        return all((permission.has_permission(request) for permission in self.permission_classes))


class BooleanField(PermissionMixin, fields.BooleanField):
    pass


class NullBooleanField(PermissionMixin, fields.NullBooleanField):
    pass


class CharField(PermissionMixin, fields.CharField):
    pass


class EmailField(PermissionMixin, fields.EmailField):
    pass


class RegexField(PermissionMixin, fields.RegexField):
    pass


class SlugField(PermissionMixin, fields.SlugField):
    pass


class URLField(PermissionMixin, fields.URLField):
    pass


class IntegerField(PermissionMixin, fields.IntegerField):
    pass


class FloatField(PermissionMixin, fields.FloatField):
    pass


class DecimalField(PermissionMixin, fields.DecimalField):
    pass


class DateField(PermissionMixin, fields.DateField):
    pass


class DateTimeField(PermissionMixin, fields.DateTimeField):
    pass


class TimeField(PermissionMixin, fields.TimeField):
    pass


class ChoiceField(PermissionMixin, fields.ChoiceField):
    pass


class MultipleChoiceField(PermissionMixin, fields.MultipleChoiceField):
    pass


class FileField(PermissionMixin, fields.FileField):
    pass


class ImageField(PermissionMixin, fields.ImageField):
    pass


class ListField(PermissionMixin, fields.ListField):
    pass


class ReadOnlyField(PermissionMixin, fields.ReadOnlyField):
    pass


class HiddenField(PermissionMixin, fields.HiddenField):
    pass


class ModelField(PermissionMixin, fields.ModelField):
    pass


class SerializerMethodField(PermissionMixin, fields.SerializerMethodField):
    pass



















import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-rest-serializer-field-permissions',
    version='0.1',
    packages=['rest_framework_serializer_field_permissions'],
    include_package_data=True,
    license='GNU General Public License v3 (GPLv3)',
    description='Field-by-field serializer permissions for Django Rest Framework.',
    long_description=README,
    url='https://intersis.org/',
    author='The Intersis Foundation',
    author_email='dev@intersis.org',
    install_requires=[
        'django>=1.7',
        'djangorestframework>=3.0.1',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
